@@ -404,10 +404,9 @@ class FrdManifestation(FrdClient):
         tei = ET.fromstring(tei)
         transform = ET.XSLT(self.xsl_doc)
         tei = transform(tei)
-        # tei = ET.tostring(tei)
         if save:
             with open(self.save_path, 'wb') as f:
-                f.write(tei)
+                f.write(ET.tostring(tei, pretty_print=True, encoding="utf-8"))
         return tei
 
     def get_man_json_dump(self, lmt=True, dmp=False):
@@ -589,7 +588,7 @@ class FrdManifestation(FrdClient):
                     json_dump = json.load(f)
             except FileNotFoundError:
                 print(f"file {self.save_path_json} not found, switching dump=True and restarting")
-                json_dump = self.get_man_json_dump(dmp=True)
+                json_dump = self.get_man_json_dump(lmt=lmt, dmp=True)
         return json_dump
 
     def get_fe_werk_signatur(self):
